#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

Name:           python-asdf-standard%{psuffix}
Version:        1.0.3
Release:        2.1
Summary:        The ASDF Standard schemas
License:        BSD-3-Clause
URL:            https://github.com/asdf-format/asdf-standard
Source:         https://files.pythonhosted.org/packages/source/a/asdf-standard/asdf_standard-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module importlib_resources >= 3 if %python-base < 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %python_version_nodots < 39
Requires:       python-importlib_resources >= 3
%endif
%if %{with test}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module asdf >= 2.8.0}
BuildRequires:  %{python_module asdf-standard = %{version}}
BuildRequires:  %{python_module astropy >= 5.0.4}
BuildRequires:  %{python_module gwcs}
# https://github.com/asdf-format/asdf-standard/pull/391
BuildRequires:  %{python_module jsonschema < 4.18}
BuildRequires:  %{python_module packaging >= 16.0}
BuildRequires:  %{python_module pytest}
%endif
BuildArch:      noarch
Provides:       python-asdf_standard = %{version}-%{release}
%python_subpackages

%description
The ASDF Standard schemas

%prep
%setup -q -n asdf_standard-%{version}
sed -i "/addopts = '--color=yes'/d" pyproject.toml

%if !%{with test}
%build
%pyproject_wheel
%endif

%if !%{with test}
%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/asdf_standard
%{python_sitelib}/asdf_standard-%{version}*-info
%endif

%changelog
* Mon Aug 21 2023 Ben Greiner <code@bnavigator.de>
- Add jsonschema < 4.18 to test dependencies
  * gh#asdf-format/asdf-standard#391
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Update to v1.0.3
  * The in progress ASDF Standard is v1.6.0
  * The stable ASDF Standard is v1.5.0
  * Update documentation to be consistent with the ASDF library
    documentation.
  * Add time-1.2.0 schema to document bugfix requiring additional
    property to be written from asdf-astropy.
  * Move packaging to pyproject.toml file from setup.cfg and
    setup.py files.
  * Remove tag from within the time-1.1.0 schema.
  * Remove tag from within the remaining schemas.
* Sun Jun  5 2022 Ben Greiner <code@bnavigator.de>
- Skip tests failing due to astropy 5.1 deprecating non-use of
  asdf-astropy -- gh#astropy/asdf-astropy#82
* Wed Apr 27 2022 Ben Greiner <code@bnavigator.de>
- update to v1.0.2
  * Pin astropy min version to 5.0.4.
* Wed Mar 16 2022 Ben Greiner <code@bnavigator.de>
- Require the main package in :test so that tests work with
  2.8 <= python-asdf < 2.10
* Sun Mar 13 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v1.0.1
- Outsourced from and required by python-asdf
